Documentation
¶
Overview ¶
Package syncinserter provides batch inserter that merges concurrent insert operations into batch insert.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrInvalidMaxBatchSize indicates invalid max batch size parameter in New. ErrInvalidMaxBatchSize = errors.New("syncinserter: batch size should be greater 0") // ErrInvalidPeriod indicates invalid period parameter in New. ErrInvalidPeriod = errors.New("syncinserter: period should be greater 0") )
Functions ¶
This section is empty.
Types ¶
type SyncInserter ¶
type SyncInserter struct {
// contains filtered or unexported fields
}
SyncInserter is bulk inserter with sync Insert API. It merges all Insert calls during period and merges them in one batch call.
Click to show internal directories.
Click to hide internal directories.